@@ -1,5 +1,5 @@
-use unicase::UniCase;
 use crate::mime_types::MIME_TYPES;
+use unicase::UniCase;
 
 include!(concat!(env!("OUT_DIR"), "/mime_types_generated.rs"));
 
@@ -34,8 +34,11 @@ pub fn get_extensions(toplevel: &str, sublevel: &str) -> Option<&'static [&'stat
 }
 
 fn map_lookup<K, V>(map: &'static [(K, V)], key: &str) -> Option<V>
-	where K: Copy + Into<UniCase<&'static str>>, V: Copy {
-	map.binary_search_by_key(&UniCase::new(key), |(k, _)| (*k).into())
+where
+	K: Copy + Into<UniCase<&'static str>>,
+	V: Copy, {
+	map
+		.binary_search_by_key(&UniCase::new(key), |(k, _)| (*k).into())
 		.ok()
 		.map(|i| map[i].1)
 }
