@@ -9,9 +9,7 @@ struct TopLevelExts {
 	subs: phf::Map<UniCase<&'static str>, (usize, usize)>,
 }
 
-pub fn get_mime_types(ext: &str) -> Option<&'static [&'static str]> {
-	map_lookup(&MIME_TYPES, ext).copied()
-}
+pub fn get_mime_types(ext: &str) -> Option<&'static [&'static str]> { map_lookup(&MIME_TYPES, ext).copied() }
 
 pub fn get_extensions(toplevel: &str, sublevel: &str) -> Option<&'static [&'static str]> {
 	if toplevel == "*" {
@@ -28,10 +26,7 @@ pub fn get_extensions(toplevel: &str, sublevel: &str) -> Option<&'static [&'stat
 	Some(&EXTS[sub.0..sub.1])
 }
 
-fn map_lookup<'key, 'map: 'key, V>(
-	map: &'map phf::Map<UniCase<&'static str>, V>,
-	key: &'key str,
-) -> Option<&'map V> {
+fn map_lookup<'key, 'map: 'key, V>(map: &'map phf::Map<UniCase<&'static str>, V>, key: &'key str) -> Option<&'map V> {
 	// FIXME: this doesn't compile unless we transmute `key` to `UniCase<&'static str>`
 	// https://github.com/sfackler/rust-phf/issues/169
 	map.get(&UniCase::new(key))
